==> tencentcloud-sdk-java-3.1.57-sources.jar: com/tencentcloudapi/gse/v20191112/models/TargetConfiguration.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.gse.v20191112.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class TargetConfiguration extends AbstractModel{

    /**
    * 预留存率
注意：此字段可能返回 null，表示取不到有效值。
    */
    @SerializedName("TargetValue")
    @Expose
    private Long TargetValue;

    /**
     * Get 预留存率
注意：此字段可能返回 null，表示取不到有效值。 
     * @return TargetValue 预留存率
注意：此字段可能返回 null，表示取不到有效值。
     */
    public Long getTargetValue() {
        return this.TargetValue;
    }

    /**
     * Set 预留存率
注意：此字段可能返回 null，表示取不到有效值。
     * @param TargetValue 预留存率
注意：此字段可能返回 null，表示取不到有效值。
     */
    public void setTargetValue(Long TargetValue) {
        this.TargetValue = TargetValue;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "TargetValue", this.TargetValue);

    }
}

==> tencentcloud-sdk-java-3.1.281-sources.jar: com/tencentcloudapi/gse/v20191112/models/TargetConfiguration.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.gse.v20191112.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class TargetConfiguration extends AbstractModel{

    /**
    * 预留存率
注意：此字段可能返回 null，表示取不到有效值。
    */
    @SerializedName("TargetValue")
    @Expose
    private Long TargetValue;

    /**
     * Get 预留存率
注意：此字段可能返回 null，表示取不到有效值。 
     * @return TargetValue 预留存率
注意：此字段可能返回 null，表示取不到有效值。
     */
    public Long getTargetValue() {
        return this.TargetValue;
    }

    /**
     * Set 预留存率
注意：此字段可能返回 null，表示取不到有效值。
     * @param TargetValue 预留存率
注意：此字段可能返回 null，表示取不到有效值。
     */
    public void setTargetValue(Long TargetValue) {
        this.TargetValue = TargetValue;
    }

    public TargetConfiguration() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public TargetConfiguration(TargetConfiguration source) {
        if (source.TargetValue != null) {
            this.TargetValue = new Long(source.TargetValue);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "TargetValue", this.TargetValue);

    }
}
